@@ -1,22 +1,4 @@
-# ##### BEGIN GPL LICENSE BLOCK #####
-#
-#  This program is free software; you can redistribute it and/or
-#  modify it under the terms of the GNU General Public License
-#  as published by the Free Software Foundation; either version 2
-#  of the License, or (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, write to the Free Software Foundation,
-#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-#
-# ##### END GPL LICENSE BLOCK #####
-
-# <pep8 compliant>
+# SPDX-License-Identifier: GPL-2.0-or-later
 
 import bpy
 from bpy.types import (
@@ -28,12 +10,17 @@ from bpy.props import (
     BoolProperty,
     StringProperty,
 )
+from bpy.app.translations import (
+    pgettext_tip as tip_,
+    pgettext_data as data_,
+)
+
 
 # For preset popover menu
 WindowManager.preset_name = StringProperty(
     name="Preset Name",
     description="Name for new preset",
-    default="New Preset"
+    default=data_("New Preset"),
 )
 
 
@@ -202,7 +189,7 @@ class AddPresetBase:
                 else:
                     os.remove(filepath)
             except Exception as e:
-                self.report({'ERROR'}, "Unable to remove preset: %r" % e)
+                self.report({'ERROR'}, tip_("Unable to remove preset: %r") % e)
                 import traceback
                 traceback.print_exc()
                 return {'CANCELLED'}
@@ -227,7 +214,7 @@ class AddPresetBase:
 
 
 class ExecutePreset(Operator):
-    """Execute a preset"""
+    """Load a preset"""
     bl_idname = "script.execute_preset"
     bl_label = "Execute a Python Preset"
 
@@ -252,7 +239,7 @@ class ExecutePreset(Operator):
         ext = splitext(filepath)[1].lower()
 
         if ext not in {".py", ".xml"}:
-            self.report({'ERROR'}, "Unknown file type: %r" % ext)
+            self.report({'ERROR'}, tip_("Unknown file type: %r") % ext)
             return {'CANCELLED'}
 
         if hasattr(preset_class, "reset_cb"):
@@ -322,7 +309,7 @@ class AddPresetCamera(AddPresetBase, Operator):
         preset_values = [
             "cam.sensor_width",
             "cam.sensor_height",
-            "cam.sensor_fit"
+            "cam.sensor_fit",
         ]
         if self.use_focal_length:
             preset_values.append("cam.lens")
@@ -330,11 +317,11 @@ class AddPresetCamera(AddPresetBase, Operator):
         return preset_values
 
 
-class AddPresetSafeAreas(AddPresetBase, Operator):
+class AddPresetCameraSafeAreas(AddPresetBase, Operator):
     """Add or remove a Safe Areas Preset"""
-    bl_idname = "safe_areas.preset_add"
+    bl_idname = "camera.safe_areas_preset_add"
     bl_label = "Add Safe Area Preset"
-    preset_menu = "SAFE_AREAS_PT_presets"
+    preset_menu = "CAMERA_PT_safe_areas_presets"
 
     preset_defines = [
         "safe_areas = bpy.context.scene.safe_areas"
@@ -452,7 +439,7 @@ class AddPresetTrackingCamera(AddPresetBase, Operator):
             "camera.pixel_aspect",
             "camera.k1",
             "camera.k2",
-            "camera.k3"
+            "camera.k3",
         ]
         if self.use_focal_length:
             preset_values.append("camera.units")
@@ -472,7 +459,7 @@ class AddPresetTrackingTrackColor(AddPresetBase, Operator):
 
     preset_values = [
         "track.color",
-        "track.use_custom_color"
+        "track.use_custom_color",
     ]
 
     preset_subdir = "tracking_track_color"
@@ -502,7 +489,7 @@ class AddPresetTrackingSettings(AddPresetBase, Operator):
         "settings.use_default_red_channel",
         "settings.use_default_green_channel",
         "settings.use_default_blue_channel",
-        "settings.default_weight"
+        "settings.default_weight",
     ]
 
     preset_subdir = "tracking_settings"
@@ -520,7 +507,7 @@ class AddPresetNodeColor(AddPresetBase, Operator):
 
     preset_values = [
         "node.color",
-        "node.use_custom_color"
+        "node.use_custom_color",
     ]
 
     preset_subdir = "node_color"
@@ -629,7 +616,7 @@ class AddPresetGpencilBrush(AddPresetBase, Operator):
 
     preset_defines = [
         "brush = bpy.context.tool_settings.gpencil_paint.brush",
-        "settings = brush.gpencil_settings"
+        "settings = brush.gpencil_settings",
     ]
 
     preset_values = [
@@ -649,7 +636,7 @@ class AddPresetGpencilBrush(AddPresetBase, Operator):
         "settings.uv_random",
         "settings.pen_jitter",
         "settings.use_jitter_pressure",
-        "settings.trim",
+        "settings.use_trim",
     ]
 
     preset_subdir = "gpencil_brush"
@@ -663,7 +650,7 @@ class AddPresetGpencilMaterial(AddPresetBase, Operator):
 
     preset_defines = [
         "material = bpy.context.object.active_material",
-        "gpcolor = material.grease_pencil"
+        "gpcolor = material.grease_pencil",
     ]
 
     preset_values = [
@@ -704,7 +691,7 @@ classes = (
     AddPresetNodeColor,
     AddPresetOperator,
     AddPresetRender,
-    AddPresetSafeAreas,
+    AddPresetCameraSafeAreas,
     AddPresetTrackingCamera,
     AddPresetTrackingSettings,
     AddPresetTrackingTrackColor,
